@@ -344,6 +344,8 @@ class Param(Arg, Generic[_Value_co]):
         choices = self.parser.choices()
         if choices is not None:
             res = {**res, "choices": choices, "type": str}
+        if self.default_value is not None:
+            res = {**res, "default": self.default_value}
         return {
             **res,
             **self.collector.argparse_argument_kwargs(),
