@@ -249,6 +249,40 @@ class ProcessorFactory(Generic[_Config]):
 
     validators: List[Callable[[_Config], Optional[Err]]]
 
+    @staticmethod
+    def _trim_docstring(docstring: str) -> str:
+        """Trims a docstring
+
+        Args:
+            docstring: Docstring to trim according to PEP 257
+
+        Returns:
+            The trimmed docstring
+        """
+        if not docstring:
+            return ""
+        # Convert tabs to spaces (following the normal Python rules)
+        # and split into a list of lines:
+        lines = docstring.expandtabs().splitlines()
+        # Determine minimum indentation (first line doesn't count):
+        indent = sys.maxsize
+        for line in lines[1:]:
+            stripped = line.lstrip()
+            if stripped:
+                indent = min(indent, len(line) - len(stripped))
+        # Remove indentation (first line is special):
+        trimmed = [lines[0].strip()]
+        if indent < sys.maxsize:
+            for line in lines[1:]:
+                trimmed.append(line[indent:].rstrip())
+        # Strip off trailing and leading blank lines:
+        while trimmed and not trimmed[-1]:
+            trimmed.pop()
+        while trimmed and not trimmed[0]:
+            trimmed.pop(0)
+        # Return a single string:
+        return "\n".join(trimmed)
+
     @staticmethod
     def make(config_type: Type[_Config]) -> ProcessorFactory[_Config]:
         """
@@ -270,6 +304,9 @@ class ProcessorFactory(Generic[_Config]):
         if description is None:
             description = config_type.__doc__
 
+        if description is not None:
+            description = ProcessorFactory._trim_docstring(description)
+
         argument_parser = argparse.ArgumentParser(
             prog=prog,
             description=description,
